@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -26,5 +26,5 @@ void GroupManagementWidgetTest::shouldHaveDefaultValues()
 
     auto mListWidget = w.findChild<QListWidget *>(QStringLiteral("mListWidget"));
     QVERIFY(mListWidget);
-    QCOMPARE(mListWidget->selectionMode(), QAbstractItemView::MultiSelection);
+    QCOMPARE(mListWidget->selectionMode(), QAbstractItemView::ExtendedSelection);
 }
